@@ -392,6 +392,9 @@ class TestSpecifier:
                 ("2!1.0", ">=2.0"),
                 ("1.0", "<2!0.1"),
                 ("2!1.0", ">2.0"),
+
+                # Test some normalization rules
+                ("2.0.5", ">2.0dev"),
             ]
         ]
         +
