@@ -140,26 +140,26 @@ class TestVersion:
             ("1.0-BETA1", "1.0b1"),
 
             # Various release candidate incarnations
-            ("1.0c", "1.0c0"),
-            ("1.0.c", "1.0c0"),
-            ("1.0.c1", "1.0c1"),
-            ("1.0-c", "1.0c0"),
-            ("1.0-c1", "1.0c1"),
-            ("1.0rc", "1.0c0"),
-            ("1.0.rc", "1.0c0"),
-            ("1.0.rc1", "1.0c1"),
-            ("1.0-rc", "1.0c0"),
-            ("1.0-rc1", "1.0c1"),
-            ("1.0C", "1.0c0"),
-            ("1.0.C", "1.0c0"),
-            ("1.0.C1", "1.0c1"),
-            ("1.0-C", "1.0c0"),
-            ("1.0-C1", "1.0c1"),
-            ("1.0RC", "1.0c0"),
-            ("1.0.RC", "1.0c0"),
-            ("1.0.RC1", "1.0c1"),
-            ("1.0-RC", "1.0c0"),
-            ("1.0-RC1", "1.0c1"),
+            ("1.0c", "1.0rc0"),
+            ("1.0.c", "1.0rc0"),
+            ("1.0.c1", "1.0rc1"),
+            ("1.0-c", "1.0rc0"),
+            ("1.0-c1", "1.0rc1"),
+            ("1.0rc", "1.0rc0"),
+            ("1.0.rc", "1.0rc0"),
+            ("1.0.rc1", "1.0rc1"),
+            ("1.0-rc", "1.0rc0"),
+            ("1.0-rc1", "1.0rc1"),
+            ("1.0C", "1.0rc0"),
+            ("1.0.C", "1.0rc0"),
+            ("1.0.C1", "1.0rc1"),
+            ("1.0-C", "1.0rc0"),
+            ("1.0-C1", "1.0rc1"),
+            ("1.0RC", "1.0rc0"),
+            ("1.0.RC", "1.0rc0"),
+            ("1.0.RC1", "1.0rc1"),
+            ("1.0-RC", "1.0rc0"),
+            ("1.0-RC1", "1.0rc1"),
 
             # Various post release incarnations
             ("1.0post", "1.0.post0"),
@@ -184,8 +184,8 @@ class TestVersion:
             ("1.01", "1.1"),
             ("1.0a05", "1.0a5"),
             ("1.0b07", "1.0b7"),
-            ("1.0c056", "1.0c56"),
-            ("1.0rc09", "1.0c9"),
+            ("1.0c056", "1.0rc56"),
+            ("1.0rc09", "1.0rc9"),
             ("1.0.post000", "1.0.post0"),
             ("1.1.dev09000", "1.1.dev9000"),
             ("00!1.2", "1.2"),
@@ -211,8 +211,8 @@ class TestVersion:
             ("1.0b2", "1.0b2"),
             ("1.0b2.post345.dev456", "1.0b2.post345.dev456"),
             ("1.0b2.post345", "1.0b2.post345"),
-            ("1.0c1.dev456", "1.0c1.dev456"),
-            ("1.0c1", "1.0c1"),
+            ("1.0rc1.dev456", "1.0rc1.dev456"),
+            ("1.0rc1", "1.0rc1"),
             ("1.0", "1.0"),
             ("1.0.post456.dev34", "1.0.post456.dev34"),
             ("1.0.post456", "1.0.post456"),
@@ -238,8 +238,8 @@ class TestVersion:
             ("7!1.0b2", "7!1.0b2"),
             ("7!1.0b2.post345.dev456", "7!1.0b2.post345.dev456"),
             ("7!1.0b2.post345", "7!1.0b2.post345"),
-            ("7!1.0c1.dev456", "7!1.0c1.dev456"),
-            ("7!1.0c1", "7!1.0c1"),
+            ("7!1.0rc1.dev456", "7!1.0rc1.dev456"),
+            ("7!1.0rc1", "7!1.0rc1"),
             ("7!1.0", "7!1.0"),
             ("7!1.0.post456.dev34", "7!1.0.post456.dev34"),
             ("7!1.0.post456", "7!1.0.post456"),
@@ -271,28 +271,28 @@ class TestVersion:
             ("1.0a1", "1.0a1"),
             ("1.0a1.post5", "1.0a1.post5"),
             ("1.0a1.post5.dev6", "1.0a1.post5.dev6"),
-            ("1.0rc4", "1.0c4"),
+            ("1.0rc4", "1.0rc4"),
             ("1.0.post5", "1.0.post5"),
             ("1!1.0", "1!1.0"),
             ("1!1.0.dev6", "1!1.0.dev6"),
             ("1!1.0a1", "1!1.0a1"),
             ("1!1.0a1.post5", "1!1.0a1.post5"),
             ("1!1.0a1.post5.dev6", "1!1.0a1.post5.dev6"),
-            ("1!1.0rc4", "1!1.0c4"),
+            ("1!1.0rc4", "1!1.0rc4"),
             ("1!1.0.post5", "1!1.0.post5"),
             ("1.0+deadbeef", "1.0"),
             ("1.0.dev6+deadbeef", "1.0.dev6"),
             ("1.0a1+deadbeef", "1.0a1"),
             ("1.0a1.post5+deadbeef", "1.0a1.post5"),
             ("1.0a1.post5.dev6+deadbeef", "1.0a1.post5.dev6"),
-            ("1.0rc4+deadbeef", "1.0c4"),
+            ("1.0rc4+deadbeef", "1.0rc4"),
             ("1.0.post5+deadbeef", "1.0.post5"),
             ("1!1.0+deadbeef", "1!1.0"),
             ("1!1.0.dev6+deadbeef", "1!1.0.dev6"),
             ("1!1.0a1+deadbeef", "1!1.0a1"),
             ("1!1.0a1.post5+deadbeef", "1!1.0a1.post5"),
             ("1!1.0a1.post5.dev6+deadbeef", "1!1.0a1.post5.dev6"),
-            ("1!1.0rc4+deadbeef", "1!1.0c4"),
+            ("1!1.0rc4+deadbeef", "1!1.0rc4"),
             ("1!1.0.post5+deadbeef", "1!1.0.post5"),
         ],
     )
